from threading import Thread
from typing import Any, Callable, Sequence

class UpdateThread(Thread):
    stop_flag: bool
    timeout: int
    call_method: Callable
    call_arguments: Sequence[Any]
    daemon: bool

    def __init__(self) -> None: ...
    def stop(self) -> None: ...
    def get_timeout(self) -> int: ...
    def set_timeout(self, timeout: int) -> None: ...
    def get_call_method(self) -> Callable: ...
    def set_call_method(self, call_method: Callable) -> None: ...
    def get_call_arguments(self) -> Sequence[Any]: ...
    def set_call_arguments(self, call_arguments: Sequence[Any]) -> None: ...
    def run(self) -> None: ...
